Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(760)

Unified Diff: third_party/WebKit/Source/platform/graphics/GraphicsLayer.h

Issue 1390123002: (WIP) Paint property hierarchy approach 1 of 2 (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/graphics/GraphicsLayer.h
diff --git a/third_party/WebKit/Source/platform/graphics/GraphicsLayer.h b/third_party/WebKit/Source/platform/graphics/GraphicsLayer.h
index 3aaac2dfabbba0238989f7cfeead9b812a139626..b30b59d853e251b81a3e07ac10162dacf7b1bdee 100644
--- a/third_party/WebKit/Source/platform/graphics/GraphicsLayer.h
+++ b/third_party/WebKit/Source/platform/graphics/GraphicsLayer.h
@@ -40,7 +40,7 @@
#include "platform/graphics/PaintInvalidationReason.h"
#include "platform/graphics/filters/FilterOperations.h"
#include "platform/graphics/paint/DisplayItemClient.h"
-#include "platform/graphics/paint/DisplayItemList.h"
+#include "platform/graphics/paint/PaintArtifact.h"
#include "platform/transforms/TransformationMatrix.h"
#include "public/platform/WebCompositorAnimationDelegate.h"
#include "public/platform/WebContentLayer.h"
@@ -55,7 +55,6 @@
namespace blink {
-class DisplayItemList;
class FloatRect;
class GraphicsContext;
class GraphicsLayer;
@@ -254,7 +253,10 @@ public:
// WebLayerScrollClient implementation.
void didScroll() override;
- DisplayItemList* displayItemList() override;
+ PaintArtifact* paintArtifact() override;
+
+ // TODO(pdr): This should be refactored so callers use paintArtifact() directly.
+ DisplayItemList* displayItemList() { return &paintArtifact()->displayItemList(); }
// Exposed for tests.
virtual WebLayer* contentsLayer() const { return m_contentsLayer; }
@@ -280,8 +282,8 @@ private:
// Callback from the underlying graphics system to draw layer contents.
void paintGraphicsLayerContents(GraphicsContext&, const IntRect& clip);
// Sets m_needsDisplay, but without invalidating the DisplayItemList. This allows us to test
// scenarios where paint needs to be re-calculated, but no DisplayItemClients were invalidated
// (such as re-paints due to change of interest rect).
void setNeedsDisplayWithoutInvalidateForTesting();
@@ -375,7 +377,7 @@ private:
GraphicsLayerDebugInfo m_debugInfo;
int m_3dRenderingContext;
- OwnPtr<DisplayItemList> m_displayItemList;
+ OwnPtr<PaintArtifact> m_paintArtifact;
friend class DisplayItemListPaintTestForSlimmingPaintV2;
};
@@ -280,8 +282,8 @@ private:
// Callback from the underlying graphics system to draw layer contents.
void paintGraphicsLayerContents(GraphicsContext&, const IntRect& clip);
- // Sets m_needsDisplay, but without invalidating the DisplayItemList. This allows us to test
- // scenarios where paint needs to be re-calculated, but no DisplayItemClients were invalidated
+ // Sets m_needsDisplay, but without invalidating the PaintArtifact. This allows us to test
+ // scenarios where paint needs to be re-calculated, but no invalidations occurred
// (such as re-paints due to change of interest rect).
void setNeedsDisplayWithoutInvalidateForTesting();

Powered by Google App Engine
This is Rietveld 408576698